package com.attestr.attestr_flowx_flutter;

import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.ProgressBar;

import com.attestr.flowx.AttestrFlowx;
import com.attestr.flowx.listener.AttestrFlowXListener;

import java.io.Serializable;
import java.util.Map;

/**
 * Copyright (c) 2022 Pegadroid IQ Solutions Pvt. Ltd.
 *
 * @Author Gaurav Naresh Pandit
 * @Since 14/06/22
 **/
public class AttestrFlowxActivity extends AppCompatActivity implements AttestrFlowXListener {

    private static final String TAG = "AttestrFlowxActivity";
    private static final String FLOW_COMPLETE = "FLOW_COMPLETE";
    private static final String FLOW_SKIP = "FLOW_SKIP";
    private static final String FLOW_ERROR = "FLOW_ERROR";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_flutter);

        ProgressBar progressBar = findViewById(R.id.flutter_progress_bar);
        progressBar.setVisibility(View.VISIBLE);
        try
        {
            if (this.getSupportActionBar() != null) {
                this.getSupportActionBar().hide();
            }
        }
        catch (Exception e){
            Intent intent = new Intent();
            setResult(Activity.RESULT_CANCELED, intent);
            finish();
        }

        Intent intent = this.getIntent();
        if (intent != null) {
            String handshakeID = intent.getStringExtra("handshake_id");
            String clientKey = intent.getStringExtra("client_key");
            String locale = intent.getStringExtra("locale");
            boolean retry = intent.getBooleanExtra("retry", false);
            Map<String, String> queryParameters = (Map<String, String>) intent.getSerializableExtra("query_parameters");
            AttestrFlowx attestrFlowx = new AttestrFlowx();
            attestrFlowx.init(clientKey, handshakeID, this);
            attestrFlowx.launch(locale, retry, queryParameters);
        }

    }

    @Override
    public void onFlowXComplete(Map<String, Object> data) {
        flowxHandler(data, FLOW_COMPLETE);
    }

    @Override
    public void onFlowXSkip(Map<String, Object> data) {
        flowxHandler(data, FLOW_SKIP);
    }

    @Override
    public void onFlowXError(Map<String, Object> data) {
        flowxHandler(data, FLOW_ERROR);
    }

    private void flowxHandler(Map<String, Object> data, String type) {
        Intent intent = new Intent();
        intent.putExtra("type", type);
        intent.putExtra("result", (Serializable) data);
        setResult(Activity.RESULT_OK, intent);
        finish();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (resultCode == RESULT_CANCELED) {
            Intent intent = new Intent();
            setResult(Activity.RESULT_CANCELED, intent);
            finish();
        }
    }

}