package com.attestr.attestr_flowx_flutter;

import android.app.Activity;
import android.content.Intent;
import android.text.TextUtils;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;

/**
 * Copyright (c) 2022 Pegadroid IQ Solutions Pvt. Ltd.
 *
 * @Author Gaurav Naresh Pandit
 * @Since 14/06/22
 **/
public class AttestrFlowxDelegate implements PluginRegistry.ActivityResultListener {

    private MethodChannel.Result pendingResult;
    private final Activity mActivity;
    // Response codes for communicating with plugin
    private static final int CODE_FLOW_COMPLETE = 0;
    private static final int CODE_FLOW_SKIP = 1;
    private static final int CODE_FLOW_ERROR = 2;
    private static final int REQUEST_CODE = 12;
    // Flowx result types
    private static final String FLOW_COMPLETE = "FLOW_COMPLETE";
    private static final String FLOW_SKIP = "FLOW_SKIP";
    private static final String FLOW_ERROR = "FLOW_ERROR";


    public AttestrFlowxDelegate(Activity activity) {
        this.mActivity = activity;
    }

    public void initiateSession(@NonNull MethodCall call,
                                @NonNull MethodChannel.Result result) {
        this.pendingResult = result;
        String handshakeID = call.argument("hs");
        String client_key = call.argument("cl");
        String locale = call.argument("lc");
        boolean retry = Boolean.TRUE.equals(call.argument("retry"));
        Map<String, String> queryParameters = call.argument("qr");
        if (!TextUtils.isEmpty(handshakeID) && !TextUtils.isEmpty(client_key)) {
            Intent flutterIntent = new Intent(mActivity, AttestrFlowxActivity.class);
            flutterIntent.putExtra("handshake_id", handshakeID);
            flutterIntent.putExtra("client_key", client_key);
            flutterIntent.putExtra("locale", locale);
            flutterIntent.putExtra("retry", retry);
            flutterIntent.putExtra("query_parameters", (Serializable) queryParameters);
            mActivity.startActivityForResult(flutterIntent, REQUEST_CODE);
        }
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        if (requestCode == REQUEST_CODE) {
            if (resultCode == Activity.RESULT_OK) {
                if (data != null) {
                    String type = data.getStringExtra("type");
                    Map<String, Object> resultData = (Map<String, Object>) data.getSerializableExtra("result");
                    if (pendingResult != null) {
                        setResult(type, resultData);
                    }
                }
            } else if (resultCode == Activity.RESULT_CANCELED) {
                pendingResult.notImplemented();
            }
        }
        return true;
    }

    private void setResult(String type, Map<String, Object> data) {
        Map<String, Object> resultData = new HashMap<>();
        switch (type) {
            case FLOW_COMPLETE:
                resultData.put("type", CODE_FLOW_COMPLETE);
                resultData.put("message", data);
                pendingResult.success(resultData);
                break;
            case FLOW_SKIP:
                resultData.put("type", CODE_FLOW_SKIP);
                resultData.put("message", data);
                pendingResult.success(resultData);
                break;
            case FLOW_ERROR:
                resultData.put("type", CODE_FLOW_ERROR);
                resultData.put("message", data);
                pendingResult.success(resultData);
                break;
        }
    }
}
