
// Copyright (c) 2022 Pegadroid IQ Solutions Pvt. Ltd.
// Created by Tushar Kalra.

import Flutter
import UIKit
import attestr_flowx

private class AttestrViewController: UIViewController, AttestrFlowxEventProtocol{
    
    private var delegate: AttestrFlowxDelegate!
    
    private let loader: UIActivityIndicatorView = {
        let loader = UIActivityIndicatorView()
        loader.translatesAutoresizingMaskIntoConstraints = false
        loader.style = .gray
        return loader
    }()
    
    private var contraints : [NSLayoutConstraint]!
    
    init(delegate: AttestrFlowxDelegate){
        self.delegate = delegate
        super.init(nibName: nil, bundle: nil)
        
        view.isOpaque = false
        view.backgroundColor = .white
        
        self.contraints = [ loader.centerXAnchor.constraint(equalTo: view.centerXAnchor),
                            loader.centerYAnchor.constraint(equalTo: view.centerYAnchor)
        ]
    }
        
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    public func onFlowxSuccess(_ data: [String : AnyObject]) {
        
        view.addSubview(loader)
        NSLayoutConstraint.activate(contraints)
        loader.startAnimating()
        
        self.dismiss(animated: true)
        
        var newData = [String : AnyObject]()
        newData["type"] =  AttestrFlowxDelegate.FLOW_COMPLETE as AnyObject
        newData["message"] = data as AnyObject
        delegate.onFlowxSuccess(newData)
    }
    
    public func onFlowxSkip(_ data: [String : AnyObject]) {
        
        view.addSubview(loader)
        NSLayoutConstraint.activate(contraints)
        loader.startAnimating()
        
        self.dismiss(animated: true, completion: nil)
        
        var newData = [String : AnyObject]()
        newData["type"] = AttestrFlowxDelegate.FLOW_SKIP as AnyObject
        newData["message"] = data as AnyObject
        delegate.onFlowxSkip(newData)
        
    }
    
    public func onFlowxError(_ data: [String : AnyObject]) {
        
        view.addSubview(loader)
        NSLayoutConstraint.activate(contraints)
        loader.startAnimating()
        
        self.dismiss(animated: true, completion: nil)
        
        var newData = [String : AnyObject]()
        newData["type"] = AttestrFlowxDelegate.FLOW_ERROR as AnyObject
        newData["message"] = data as AnyObject
        delegate.onFlowxError(newData)
        
    }
}

public class AttestrFlowxDelegate: NSObject {
    
    private var pendingResult: FlutterResult!
    
    static let FLOW_COMPLETE = 0
    static let FLOW_SKIP = 1
    static let FLOW_ERROR = 2
    
    private var vc : FlutterViewController!
    private var avc: UIViewController!
    
    override init(){
        super.init()
        self.vc = UIApplication.shared.delegate?.window??.rootViewController  as? FlutterViewController
        self.avc = AttestrViewController(delegate: self)
        avc.modalPresentationStyle = .fullScreen
    }
    
    public func launchFlow(options : Dictionary<String, Any>, result: @escaping FlutterResult){
        
        self.pendingResult = result
        
        let hs = options["hs"] as? String
        let cl = options["cl"] as? String
        let lc = options["lc"] as? String
        let retry = options["retry"] as? Bool
        let qr = options["qr"] as? [String : String]
        
        vc.show(avc, sender: vc)
        let flow = AttestrFlowx().initialize(cl: cl!, hs: hs!, avc)
        flow?.launch(lc: lc, retry: retry!, qr: qr)
        
    }
    
    public func onFlowxSuccess(_ data: [String : AnyObject]) {
        
        pendingResult(data as NSDictionary)
    }
    
    public func onFlowxSkip(_ data: [String : AnyObject]) {
        
        pendingResult(data as NSDictionary)
    }
    
    public func onFlowxError(_ data: [String : AnyObject]) {
        
        pendingResult(data as NSDictionary)
        
    }
    
}

